@@ -9,17 +9,12 @@
 #' @family aggregations
 #' @return A FeatureCollection of \code{\link{data-Polygon}} features with
 #' properties listed as \code{out_field}
-#' @examples
+#' @examples \dontrun{
 #' poly <- lawn_data$polygons_average
 #' pt <- lawn_data$points_average
-#' lawn_max(poly, pt, 'population', 'max')
-#' @examples \dontrun{
-#' lawn_max(poly, pt, 'population', 'max') %>% view
+#' lawn_max(poly, pt, 'population')
 #' }
-lawn_max <- function(polygons, points, in_field, out_field, lint = FALSE) {
+lawn_max <- function(polygons, points, in_field, out_field = "max", lint = FALSE) {
   lawnlint(list(polygons, points), lint)
-  py <- convert(polygons)
-  pt <- convert(points)
-  ct$eval(sprintf("var max = turf.max(%s, %s, '%s', '%s');", py, pt, in_field, out_field))
-  as.fc(ct$get("max"))
+  calc_math("max", convert(polygons), convert(points), in_field, out_field)
 }
