@@ -31,7 +31,7 @@ lawn_random <- function(type = "points", n = 10, bbox = NULL,
                         num_vertices = NULL, max_radial_length = NULL) {
 
   jj <- jsonlite::toJSON(cmp(list(bbox = bbox, num_vertices = num_vertices,
-                                  max_radial_length = max_radial_length)))
+                                  max_radial_length = max_radial_length)), auto_unbox = TRUE)
   ct$eval(sprintf("var rnd = turf.random('%s', %s, %s);", type, n, jj))
   as.fc(ct$get("rnd"))
 }
