@@ -19,6 +19,17 @@
 lawn_remove <- function(features, property, value, lint = FALSE) {
   features <- convert(features)
   lawnlint(features, lint)
-  ct$eval(sprintf("var rmv = turf.remove(%s, '%s', '%s');", features, property, value))
+  ct$eval('
+    fun = function(cc, k, v) {
+      var nfc = turf.featureCollection([]);
+      for (var i = 0; i < cc.features.length; i++) {
+          if(cc.features[i].properties[k] === v) {
+          nfc.features.push(cc.features[i]);
+        }
+      }
+      return nfc;
+    }
+  ')
+  ct$eval(sprintf("var rmv = fun(%s, '%s', '%s');", features, property, value))
   as.fc(ct$get("rmv"))
 }
