@@ -57,6 +57,6 @@ test_that("lawn_inside returns correct values", {
 
 test_that("lawn_inside fails correctly", {
   expect_error(lawn_inside(), "argument \"point\" is missing, with no default")
-  expect_error(lawn_inside("{}", poly), "Cannot read property 'coordinates' of undefined")
+  expect_error(lawn_inside("{}", poly), "A coordinate, feature, or point geometry is required")
   expect_error(lawn_inside(point1, point2), "Cannot read property 'length' of undefined")
 })
