@@ -15,17 +15,19 @@ test_that("lawn_max returns correct classes", {
 })
 
 test_that("in_field and out_field parameter works as expected", {
-  expect_equal(length(lawn_max(poly, pt, 'population2', 'max')$features$properties), 0)
-  expect_named(lawn_max(poly, pt, 'population', 'bears')$features$properties, 'bears')
+  expect_equal(length(na.omit(lawn_max(poly, pt, 'population2')$features$properties$max)), 0)
+  expect_named(lawn_max(poly, pt, 'population', 'bears')$features$properties,
+               c('values', 'bears'))
 })
 
 test_that("lawn_max fails correctly", {
   # missing arguments
   expect_error(lawn_max(), "argument \"polygons\" is missing, with no default")
   # wrong in_field param leads to no ouput for max
-  expect_equal(length(lawn_max(poly, pt, 'population2', 'max')$features$properties), 0)
+  expect_equal(length(na.omit(lawn_max(poly, pt, 'population2')$features$properties$max)), 0)
   # can't pass in a character string to cellWidth
   expect_error(lawn_max(poly, "{}", 'population', 'max'), "Cannot call method")
   # can't pass in a character string to cellWidth
-  expect_error(lawn_max(poly, "{}", 'population', 'max', lint = TRUE), "The type property is required")
+  expect_error(lawn_max(poly, "{}", 'population', 'max', lint = TRUE),
+               'Line 1 - "type" member required')
 })
